@@ -160,20 +160,24 @@ class Atila (mixin.MixIn):
                     response.set_header ("Access-Control-Allow-Headers", requeste_headers)
                 status_code = 200
 
-            else:
-                if not self.is_allowed_origin (request, options.get ("access_control_allow_origin", self.access_control_allow_origin)):
-                    status_code =  403
-                elif not self.is_authorized (request, options.get ("authenticate", self.authenticate)):
-                    status_code =  401
+            elif not self.is_authorized (request, options.get ("authenticate", self.authenticate)):
+                status_code =  401
 
-        if status_code in (401, 200):
-            authenticate = options.get ("authenticate", self.authenticate)
-            if authenticate:
-                request.response.set_header ("Access-Control-Allow-Credentials", "true")
+            access_control_allow_origin = options.get ("access_control_allow_origin", self.access_control_allow_origin)
 
-        access_control_allow_origin = options.get ("access_control_allow_origin", self.access_control_allow_origin)
-        if access_control_allow_origin and access_control_allow_origin != 'same':
-            request.response.set_header ("Access-Control-Allow-Origin", ", ".join (access_control_allow_origin))
+        else:
+            access_control_allow_origin = self.access_control_allow_origin
+
+        if access_control_allow_origin:
+            if not self.is_allowed_origin (request, access_control_allow_origin):
+                status_code =  403
+
+            elif access_control_allow_origin != 'same':
+                origin = request.get_header ('Origin')
+                if origin:
+                    request.response.set_header ("Access-Control-Allow-Origin", origin)
+                    if "*" not in access_control_allow_origin:
+                        request.response.set_header ("Access-Control-Allow-Credentials", "true")
 
         return current_app, method, kargs, options, status_code
 
