@@ -407,6 +407,9 @@ class MixIn (
         self.logger = logger
 
     def log (self, msg, type = "info"):
+        if self.logger is None:
+            if type != 'info':
+                raise SystemError ('[{}] {}'.format (type, msg))
         self.logger (msg, type)
 
     def trace (self):
