@@ -246,6 +246,9 @@ class WAS (wsgiappservice.WAS):
     def File (self, *args, **karg):
         return self.response.File (*args, **karg)
 
+    def Static (self, *args, **karg):
+        return self.response.Static (*args, **karg)
+
     def proxypass (self, alias, path, timeout = 3):
         def respond (was, rs):
             resp = rs.dispatch ()
