@@ -282,7 +282,7 @@ class Executor:
 			content = [request.response.with_explain ('400 Not My Fault', *e.args [:1])]
 		except HTTPError as e:
 			self.rollback ()
-			content = [request.response.with_explain (e.status, e.explain, e.errno)]
+			content = [request.response.with_explain (e.status, e.explain or (self.was.app.debug and e.exc_info), e.errno)]
 		except:
 			self.was.traceback ()
 			self.rollback ()
